.. Lens documentation master file, created by
   sphinx-quickstart on Tue Sep 27 10:49:51 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Lens
====

.. toctree::
   :maxdepth: 2

   tutorial
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
